# Convnetional Ticket

This is a template for commitizen. This is based on conventional commits. It provides extra options to enter ticket number in commit message and changelog.

## Prerequisite 

You must have `commitizen` installed before installing this package.
To install commitizen run 

`pip install -U commitizen`

## Usage

`pip install -U conventional_ticket`

In `.cz.toml` or project file of commmitizen use `cz_conventional_ticket` in `name` field

Example `.cz.toml`

```
[tool.commitizen]
name = "cz_convnetional_ticket"
version = "5.2.0"
tag_format = "v$version"
```

## Author
Gohar Anwar (gohar@goharanwar.com)
